This function formats an object of class koma_seq for better readability.
It formats the equations to ensure proper spacing around operators and aligns
the equations for a cleaner display.
Usage
# S3 method for class 'koma_seq'
format(x, ...)This function formats an object of class koma_seq for better readability.
It formats the equations to ensure proper spacing around operators and aligns
the equations for a cleaner display.
# S3 method for class 'koma_seq'
format(x, ...)