Get endogenous variables from a system of equations
Source:R/system_of_equations.R
get_endogenous_variables.RdThis function takes a system of equations and returns it's endogenous variables.
R/system_of_equations.R
get_endogenous_variables.RdThis function takes a system of equations and returns it's endogenous variables.