This function checks if the given object inherits from the class koma_seq,
indicating that it represents a system of equations.
This function checks if the given object inherits from the class koma_seq,
indicating that it represents a system of equations.