Skip to contents

Visualize running means (cumulative averages) from running_mean() with a light grey band over the grace-window region.

Usage

running_mean_plot(x, ...)

Arguments

x

A koma_estimate object.

...

Additional arguments controlling the plot. See Details in running_mean().

Value

A ggplot object, or a plotly object when interactive = TRUE and plotly is available.

Details

Additional plot arguments in ...:

scales

Facet scale option passed to ggplot2::facet_wrap. Default is "free_y".

facet_ncol

Optional integer number of columns for facets.

interactive

Logical. If TRUE and plotly is available, return an interactive plot via plotly::ggplotly. Default is FALSE.