Prints HDI intervals for coefficients in a table per equation.
Usage
# S3 method for class 'koma_estimate_hdi'
summary(object, ..., variables = NULL, params = NULL, digits = 3)Prints HDI intervals for coefficients in a table per equation.
# S3 method for class 'koma_estimate_hdi'
summary(object, ..., variables = NULL, params = NULL, digits = 3)