Prints HDR intervals for coefficients in a table per equation.
Usage
# S3 method for class 'koma_estimate_hdr'
summary(object, ..., variables = NULL, params = NULL, digits = 3)Prints HDR intervals for coefficients in a table per equation.
# S3 method for class 'koma_estimate_hdr'
summary(object, ..., variables = NULL, params = NULL, digits = 3)